SLCWAInstances
==============

.. currentmodule:: pykeen.triples

.. autoclass:: SLCWAInstances
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SLCWAInstances.collate
      ~SLCWAInstances.from_triples
      ~SLCWAInstances.get_collator

   .. rubric:: Methods Documentation

   .. automethod:: collate
   .. automethod:: from_triples
   .. automethod:: get_collator
